#!/usr/bin/perl -w

###########################################################################
# Network Configuration Store (NCS) Version 3.0
#
# $Id: CS3.pl,v 1.31.2.1 2008/08/09 16:28:13 amcwilliam Exp $
#
# Copyright (C) 2006 - 2008 Alasdair McWilliam and the NCS Project.
# All rights reserved. http://sf.net/projects/ncs
#
# This software is provided under the W3C Software Licence. Please refer to
# the LICENCE.txt file in the top-level installation path for terms.
#
###########################################################################

use strict;
use Cwd qw(realpath);

# Get the base NCS path and load the module library

my $CS_PATH;
my $CS_LIB;

BEGIN
{
	use File::Basename;

	$CS_PATH = dirname(realpath($0));
	$CS_LIB = "$CS_PATH/lib";
}

use lib $CS_LIB;

use Config::IniFiles;
use Parallel::ForkManager;

use NCS::Util;
use NCS::Loader;
use NCS::LogMgr;
use NCS::Snmp;
use NCS::Alert;
use NCS::DB;

# Space for Global Variables
my %sys = (
	path	=> $CS_PATH,
	ini	=> undef,
	util	=> undef,
	loader	=> undef,
	args	=> undef,
	logmgr	=> undef,
	db	=> undef,
);

sub check_options
{
}

###########################################################################

$sys{args} = NCS::Loader::parse_options and check_options;

# Now we read any settings we need
#
$sys{ini} = new Config::IniFiles( -file => $CS_PATH."/db.ini", -nocase => 1 ) or exit;

# Next step, setup some basics.
#
$sys{loader} = new NCS::Loader(\%sys);
$sys{util} = new NCS::Util(\%sys);
$sys{logmgr} = new NCS::LogMgr(\%sys);

#
# Setup our parent database context and load our NCS options.
# Returning undef means the [db] INI section is invalid.
#

$sys{db} = new NCS::DB(\%sys, "PARENT") or exit;
$sys{loader}->connect_database or exit;
$sys{loader}->load_options_db or exit;

#
# Now setup our log manager and do a bit of cleanup on the log path.
#

$sys{logmgr}->setup_logdir;
$sys{logmgr}->rotate_logdirs;

#
# Now we begin to read device data...
#

$sys{loader}->load_device_db or exit;
$sys{loader}->load_alerts_db or exit;

#
# Start the TFTP server...
#
$sys{loader}->start_tftp_svc or exit;

#
# Initialise Fork Manager
#
my $fork = new Parallel::ForkManager($sys{loader}->{max_threads});

#
# Do some work...
#
foreach my $device (@{$sys{loader}->{devices}})
{
	$fork->start and next;
	if ($device->load_db)
	{
		$device->device_process;
	}
	$fork->finish;
}

$fork->wait_all_children;

#
# Now walk the alert group list and process them.
#

foreach my $a (@{$sys{loader}->{alerts}})
{
	$a->process_targets;
}

### Clean up

$sys{db}->close;
$sys{loader}->stop_tftp_svc;





